import express from 'express';
import * as dotenv from 'dotenv';
import { deleteUnsignedUsers } from './service/userService';
import bodyParser from 'body-parser';
import { connectToDb } from './db';
import cookieParser from 'cookie-parser';
import authRoutes from './routes/auth';
import userRoutes from './routes/user';
import groupRoutes from './routes/group';
import pdfRoutes from './routes/pdf';
import mailRoutes from './routes/mail';

dotenv.config();

const port: number = 8000;
const app = express();

//Middlewares
app.use(bodyParser.json({ limit: '50mb' }));
app.use(bodyParser.urlencoded({ limit: '50mb', extended: true }));
app.use(cookieParser());

try {
    if (process.env.NODE_ENV !== "test") {
        connectToDb((error: any) => {
			if (!error) {
				app.listen(port, () => {
					console.log(`Now listening on port ${port}`);
				});
				setInterval(deleteUnsignedUsers, 24 * 60 * 60 * 1000);
			}
		});
    }
  } catch (error) {
    if (error instanceof Error) {
      console.error(`Error: ${error.message}`);
    }
    console.error("Something is wrong (check your .env-file)");
  }

//App routes
app.use('/api/auth', authRoutes)
app.use('/api/user', userRoutes)
app.use('/api/group', groupRoutes)
app.use('/api/pdf', pdfRoutes)
app.use('/api/mail', mailRoutes)

export default app;