import { getNtnuiToken, getNtnuiProfile, isValidNtnuiToken } from 'ntnui-tools';
import { Request, Response } from 'express';

const login = async (req: Request, res: Response) => {
	try {
		const tokens = await getNtnuiToken(
			req.body.phone_number,
			req.body.password
		);

		const profile = await getNtnuiProfile(tokens.access);

		const hasAccess = profile.data.memberships.some(
			(membership) =>
				membership.type === 'leader' ||
				membership.slug === 'hovedstyret'
		);

		if (hasAccess) {
			return res
				.cookie('accessToken', tokens.access, {
					maxAge: 1800000, // 30 minutes
					httpOnly: true,
					secure: process.env.NODE_ENV === 'production',
					sameSite: true
				})
				.cookie('refreshToken', tokens.refresh, {
					maxAge: 86400000, // 1 day
					httpOnly: true,
					secure: process.env.NODE_ENV === 'production',
					sameSite: true
				})
				.status(200)
				.json({ message: 'Successful login' });
		}

		//This is returned when the user exists, but is not a group leader or a member of hovedstyret
		return res.status(401).send({
			message: 'Unauthorized'
		});
	} catch (error) {
		//This is returned when the user does not exist
		console.log(error);
		return res.status(401).send({
			message: 'Unauthorized'
		});
	}
};

const logout = async (req: Request, res: Response) => {
	return res
		.clearCookie('accessToken')
		.clearCookie('refreshToken')
		.status(200)
		.json({ message: 'Successfully logged out' });
};

const checkToken = async (req: Request, res: Response) => {
	const cookies = req.headers.cookie;
	let tokenIsValid = false;

	if (cookies) {
		let { accessToken } = req.cookies;
		if (accessToken) {
			tokenIsValid = await isValidNtnuiToken(accessToken);
			return res.status(200).json({
				validToken: tokenIsValid
			});
		} else {
			//Returned if the user only has cookies set, but no accessToken
			return res.status(401).send({
				message: 'Unauthorized',
				validToken: tokenIsValid
			});
		}
	} else {
		//Returned if the user does not have any cookies set
		return res.status(401).send({
			message: 'Unauthorized',
			validToken: tokenIsValid
		});
	}
};

export { login, logout, checkToken };
