import { Request, Response } from 'express';
import nodemailer from 'nodemailer';
import { getDb } from '../db';

const sendMailForSigning = async (userId: string, email: string) => {
	const html: string = `
        <img src="cid:ntnuiLogo" style="width: 100px;" />
        <h1>Du har mottat en kontrakt</h1>
        <p>Taushetserklæring er klar for å bli signert.</p>
        <a href="https://nda.ntnui.no/sign-nda/${userId}">Gå til kontrakten</a><br>
        <p>Du kan også kopiere inn følgende lenke i nettleseren:</p>
        <a href="https://nda.ntnui.no/sign-nda/${userId}">https://nda.ntnui.no/sign-nda/${userId}</a>
    `;

	const transporter = nodemailer.createTransport({
		host: process.env.SMTP_HOST,
		port: Number(process.env.SMTP_PORT),
		auth: {
			user: process.env.SMTP_USERNAME,
			pass: process.env.SMTP_PASSWORD
		}
	});

	await transporter.sendMail({
		from: process.env.SMTP_SENDER,
		to: email,
		subject: 'Taushetserklæring for signering',
		html: html,
		attachments: [
			{
				filename: 'ntnui.png',
				path: './src/assets/ntnui.png',
				cid: 'ntnuiLogo'
			}
		]
	});
};

const sendConfirmationEmail = async (req: Request, res: Response) => {
	try {
		const userId = req.body.userId;

		const dbConnection = getDb();
		//Retreives the users email by their ID
		const userEmail = await dbConnection
			.collection('users')
			.findOne({ _id: userId }, { projection: { _id: 0, email: 1 } });

		if (!userEmail)
			return res.status(500).send({ error: 'Could not get email' });

		//Attaches the signed base64 contract to the email
		const base64Contract = req.body.contract;

		const html: string = `
            <img src="cid:ntnuiLogo" style="width: 100px;" />
            <p>Signert taushetserklæring er vedlagt.</p>
        `;

		const transporter = nodemailer.createTransport({
			host: process.env.SMTP_HOST,
			port: Number(process.env.SMTP_PORT),
			auth: {
				user: process.env.SMTP_USERNAME,
				pass: process.env.SMTP_PASSWORD
			}
		});

		await transporter.sendMail({
			from: process.env.SMTP_SENDER,
			to: userEmail.email,
			subject: 'Kopi av signert taushetserklæring',
			html: html,
			attachments: [
				{
					filename: 'ntnui.png',
					path: './src/assets/ntnui.png',
					cid: 'ntnuiLogo'
				},
				{
					filename: 'Taushetserklæring.pdf',
					path: 'data:application/pdf;base64,' + base64Contract
				}
			]
		});

		return res.status(200).send({ message: 'Email sent successfully' });
	} catch (error) {
		console.log(error);
		return res.status(500).send({ error: 'Could not send email' });
	}
};

export { sendMailForSigning, sendConfirmationEmail };