import request from "supertest";
import app from "../index";
import { loginLeader, loginHovedstyret, logoutTest } from "./utils";
import { MongoMemoryServer } from 'mongodb-memory-server';
import { MongoClient } from 'mongodb';

describe("API test auth", () => {
    let con: MongoClient;
    let mongoServer: MongoMemoryServer;

    beforeAll(async () => {
    mongoServer = await MongoMemoryServer.create();
    con = await MongoClient.connect(mongoServer.getUri(), {});
    });

    afterAll(async () => {
    if (con) {
        await con.close();
    }
    if (mongoServer) {
        await mongoServer.stop();
    }
    });
    
    loginLeader();

    loginHovedstyret();

    logoutTest();

    test("POST/ Login in with wrong password: should return status code 401", async () => {
        const response = await request(app)
        .post("/api/auth/login")
        .send({
            phone_number: "+4766669999",
            password: "svom123",
        })
        expect(response.statusCode).toBe(401);
        expect(response.body["message"]).toBe("Unauthorized");
    });

    test("POST/ Login in with an account that is not a leader or in hovedstyret: should return status code 401", async () => {
        const response = await request(app)
        .post("/api/auth/login")
        .send({
            phone_number: "+4799996666",
            password: "svom2",
        })
            expect(response.statusCode).toBe(401);
            expect(response.body["message"]).toBe("Unauthorized");
    });
});