import { PDFDocument } from 'pdf-lib';

async function getPdfAsBase64(pdfDoc: PDFDocument): Promise<string> {
	return new Promise<string>(async (resolve, reject) => {
		try {
			const pdfBytes = await pdfDoc.save();
			const pdfBase64 = Buffer.from(pdfBytes).toString('base64');
			resolve(pdfBase64);
		} catch (err) {
			reject(err);
		}
	});
}

async function base64ToPdf(encodedPdf: string): Promise<PDFDocument> {
	return new Promise<PDFDocument>(async (resolve, reject) => {
		try {
			const buffer = Buffer.from(encodedPdf, 'base64');
			const pdfDoc = await PDFDocument.load(buffer);
			resolve(pdfDoc);
		} catch (err) {
			reject(err);
		}
	});
}

export { getPdfAsBase64, base64ToPdf };
