/// <reference types="cypress" />

describe('Home', () => {

    beforeEach(() => {
        cy.visit('/login')

        cy.get('[data-cy="phone-input"]').click().type('98765432')
        cy.get('[data-cy="password-input"]').click().type('hs69')
        cy.get('[data-cy="login-submit"]').click()

        cy.intercept('GET', '/api/user/users?groupslug=svomming', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        cy.intercept('GET', '/api/user/users?groupslug=hovedstyret', { fixture: 'hovedstyretGroupUsers.json' }).as('getUsers')
        //This can be removed when homepage no longer loads empty group
        cy.intercept('GET', '/api/user/users?groupslug=', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        cy.intercept('GET','/api/group/groups',{ fixture: 'groups.json' }).as('getGroups')
        cy.intercept('GET','/api/user/loggedInUser', { fixture: 'loggedInUserInfo.json' }).as('loggedInUser')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractFirstSignature.json' }).as('editContract')

        cy.wait(['@getUsers','@getGroups'])
    })
    
    describe('UserList', () => {
        it('UserList shows "Ingen Brukere" when no matching users exist', () => {
            cy.get('[data-cy="user-search-input"]').click().type('Non existent user')
            
            cy.get('[data-cy="no-users-text"').should('be.visible')
        })
    
        it('Loadingicon shows when loading in users', () => {
            cy.reload()
            cy.get('[data-cy="user-loading-icon"]')
        })
    })

    describe('Functionalities', () => {
        it('Manual mail-send navigates to /send-nda', () => {

            cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')

            cy.get('[data-cy="send-by-mail-button"').click()
    
            cy.get('[data-cy="send-by-mail-button"').should('be.visible')
    
            cy.get('[data-cy="send-by-mail-email-input"]').click().type('test@test.com')
            cy.get('[data-cy="send-by-mail-firstname-input"]').click().type('Test')
            cy.get('[data-cy="send-by-mail-lastname-input"]').click().type('Tester')
            cy.get('[data-cy="send-by-mail-role-input"]').click().type('Leder')
            cy.get('[data-cy="send-by-mail-group-input"]').click().type('Svømming')
            cy.get('[data-cy="send-by-mail-submit"]').click()
    
            cy.url().should('include','send-nda')
        });
        
        //Removed this test as most of its functionality is directly tied to the npm package
        //jszip which can be asumed to work. Kept the commented test in case other related
        //functionality surrounding the downloading process needs to be tested

        //If tests are run with cypress:open the folder will not be removed
        //from /downloads before running. CI tests with cypress:run does empty the folder
        // it('Checks that the dowload button dowloads a folder with contracts', () => {
        //     cy.get('[data-cy="download-button"]').click()
    
        //     cy.readFile('cypress/downloads/svomming-contracts.zip', {timeout: 10000})
        // })
    })

    describe('UserRow', () => {

        beforeEach(() => {
            cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')
        })

        //This could somehow check that the right info is being sent
        it('Generate contract button navigates to /send-nda', () => {
            cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

            cy.url().should('include','/send-nda')
        })

        //This could somehow check that the right info is being sent
        it('Generate new contract button navigates to /send-nda', () => {
            cy.get('[data-cy="generate-new-contract-button"]:not(:hidden)').first().click()
            
            cy.url().should('include','/send-nda')
        })

        it('View contract button shows contract', () => {

            cy.intercept('POST','/api/user/getContractByUserEmail', { delay: 2000, fixture: 'userContract.json' }).as('getContract')

            cy.get('[data-cy="view-contract-button"]:not(:hidden)').first().click()

            cy.get('[data-cy="contract-loading"]').should('be.visible')

            cy.wait('@getContract')

            cy.get('[data-cy="contract-view"]').should('be.visible')    
            
            cy.get('[data-cy="close-contract-view"]').click()
            
            cy.get('[data-cy="contract-view"]').should('not.exist')
        })
    })
    
    describe('Filtering', () => {

        it('Shows correct results when searching', () => {
            cy.get('[data-cy="user-search-input"]').click().type('Petter Plask')
    
            cy.get('[data-cy="user-name"]').should('have.length',1)
            cy.get('[data-cy="user-name"]').should('contain.text',"Petter Plask")
    
            cy.get('[data-cy="user-search-input"]').clear().click()
    
            cy.get('[data-cy="user-name"]').should('have.length',5)
    
            cy.get('[data-cy="user-search-input"]').clear().click().type('x')
            cy.get('[data-cy="user-name"]').should('have.length',0)
        })

        it('Shows correct results when toggling signstatus-button', () => {
            cy.get('[data-cy="sign-status-button"]').click()
    
            cy.get('[data-cy="sign-status-button"]').contains('Vis alle')
            cy.get('[data-cy="user-name"]').should('have.length',4)
            cy.get('[data-cy="user-name"]').should('contain.text',"Petter Plask")
    
            cy.get('[data-cy="sign-status-button"]').click()
    
            cy.get('[data-cy="sign-status-button"]').contains('Vis kun usignerte')
            cy.get('[data-cy="user-name"]').should('have.length',5)
        })

        it('Shows correct results when selecting group', () => {
            cy.get('[data-cy="group-input"').click().clear().type('Hovedstyret')
            cy.get('[data-cy="user-name"]').should('have.length',4)
            cy.get('[data-cy="user-name"]').should('contain.text',"Leder Ledersen")
    
            cy.get('[data-cy="group-input"').click().clear().type('Bandy')
            cy.get('[data-cy="user-name"]').should('have.length',0)
        })

        it('Group list opens and closes correctly', () => {
            cy.get('[data-cy="group-list-arrow"]').click()
            cy.get('[data-cy="group-list"]').should('be.visible')
    
            cy.get('[data-cy="group-list-arrow"]').click()
            cy.get('[data-cy="group-list"]').should('not.exist')
    
            cy.get('[data-cy="group-input"').click().clear().type('Hovedstyret')
            cy.get('[data-cy="group-list"]').should('be.visible')
    
            cy.get('[data-cy="home-page"]').click(10,10)
            cy.get('[data-cy="group-list"]').should('not.exist')
        })
    
        it('GroupSelector shows correct warnings', () => {
            cy.get('[data-cy="group-input"').click().clear().trigger('keydown', {
                key: 'Enter',
              });
            cy.get('[data-cy="group-warning"').should('contain','Velg en gruppe')
    
            cy.get('[data-cy="group-input"').click().clear().type('x').trigger('keydown', {
                key: 'Enter',
              });
            cy.get('[data-cy="group-warning"').should('contain','Gruppen eksisterer ikke')
    
            cy.get('[data-cy="group-input"').click().clear().type('Svømming').trigger('keydown', {
                key: 'Enter',
              });
            cy.get('[data-cy="group-warning"').should('not.exist')
        })
        
        it('Shows correct results when filtering by year', () => {
            cy.get('[data-cy=yearpicker-button]').click()
    
            cy.get('[data-cy="year-picker"').should('be.visible')
    
            cy.get('[data-cy=specific-year-button]').contains('2018').click()
            cy.get('[data-cy="user-name"]').should('have.length',2)
            cy.get('[data-cy="user-name"]').should('contain.text',"Søren Sørensen")
    
            cy.get('[data-cy=yearpicker-button]').click()
            cy.get('[data-cy=specific-year-button]').contains('2020').click()
            cy.get('[data-cy="user-name"]').should('have.length',0)
    
            cy.get('[data-cy=yearpicker-button]').click()
            cy.get('[data-cy=home-page]').click(10,10)
            cy.get('[data-cy=year-picker]').should('not.exist')
        })
    })

})    