/// <reference types="cypress" />

describe('Login', () => {

  beforeEach(() => {
    cy.clearAllCookies()
    cy.intercept('GET','/api/user/loggedInUser', { fixture: 'loggedInUserInfo.json' }).as('loggedInUser')
    cy.intercept('GET', '/api/user/users?groupslug=svomming', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
    //This can be removed when homepage no longer loads empty group
    cy.intercept('GET', '/api/user/users?groupslug=', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
    cy.intercept('GET','/api/group/groups',{ fixture: 'groups.json' }).as('getGroups')
  })

  it('navigates to home on successfull login', () => {
    cy.visit('/login')

    cy.get('[data-cy="phone-input"]').click().type('98765432')
    cy.get('[data-cy="password-input"]').click().type('hs69')
    cy.get('[data-cy="login-submit"]').click()

    cy.url().should('not.include','/login')
  })

  it('shows error message on unsuccessfull login', () => {
    cy.visit('/login')

    cy.get('[data-cy="phone-input"]').click().type('98765432')
    cy.get('[data-cy="password-input"]').click().type('wrong_password')
    cy.get('[data-cy="login-submit"]').click()

    cy.url().should('include','/login')
    cy.get('[data-cy="login-error"').should('exist')
  })

  it('navigates to home on existent refreshToken', () => {
    cy.visit('/login')

    cy.get('[data-cy="phone-input"]').click().type('98765432')
    cy.get('[data-cy="password-input"]').click().type('hs69')
    cy.get('[data-cy="login-submit"]').click()

    cy.wait(1000) 

    cy.visit('/login')

    cy.url().should('not.include','login')
  })

  it('navigates to login on non-existent refreshToken', () => {
    cy.visit('/')

    cy.wait(1000)

    cy.url().should('include','login')
  })

  it('shows loadingicon on slow login', () => {
    cy.visit('/login')

    cy.get('[data-cy="phone-input"]').click().type('98765432')
    cy.get('[data-cy="password-input"]').click().type('hs69')
    cy.get('[data-cy="login-submit"]').click()

    cy.get('[data-cy="login-loading"]').should('exist')
  })
})