/// <reference types="cypress" />

import 'cypress-file-upload';

describe('ProfileView', () => {

    beforeEach(() => {
        cy.visit('/login')

        cy.get('[data-cy="phone-input"]').click().type('98765432')
        cy.get('[data-cy="password-input"]').click().type('hs69')
        cy.get('[data-cy="login-submit"]').click()

        cy.intercept('GET', '/api/user/users?groupslug=svomming', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        cy.intercept('GET', '/api/user/users?groupslug=hovedstyret', { fixture: 'hovedstyretGroupUsers.json' }).as('getUsers')
        //This can be removed when homepage no longer loads empty group
        cy.intercept('GET', '/api/user/users?groupslug=', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        cy.intercept('GET','/api/group/groups',{ fixture: 'groups.json' }).as('getGroups')
        cy.intercept('GET','/api/user/loggedInUser', { fixture: 'loggedInUserInfo.json' }).as('loggedInUser')

        cy.wait(['@getUsers','@getGroups'])

        cy.get('[data-cy="profile-view-button"]').click()

        cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')
        cy.intercept('PUT','/api/user/updateSignature', { fixture: 'updateSignature.json' }).as('updateSignature')
    })
  
    it('file-upload uploads file', () => {
      cy.get('[data-cy="signature-upload"]').click()
      cy.fixture('test_signature.png').as('signatureFixture')
      cy.get('[data-cy="signature-file-input"]').selectFile('@signatureFixture',{ force: true })
      
      cy.get('[data-cy="signature-view-button"]').click()
      cy.get('[data-cy="signature-view"]').should('have.attr', 'src').should('not.be.empty')
    })

    it('opens sign component on signature draw upload button', () => {
        cy.get('[data-cy="signature-draw-upload"').click()
        cy.get('[data-cy="signature-canvas-input"]').should('be.visible')
    })

    it('shows signature upload loading and confirmation', () => {
        cy.intercept('PUT','/api/user/updateSignature', { fixture: 'updateSignature.json', delay: 1000 }).as('updateSignature')

        cy.get('[data-cy="signature-draw-upload"]').click()
        cy.get('[data-cy="signature-canvas-input"]').click(10,10)
        cy.get('[data-cy="use-signature-button"]').click()

        cy.get('[data-cy="signature-upload-loading"]').should('be.visible')

        cy.get('[data-cy="signature-upload-confirmation"]').should('be.visible')

        cy.get('[data-cy="close-signature-upload-confirmation"]').click()

        cy.get('[data-cy="signature-upload-confirmation"]').should('not.exist')
    })

    it('shows signature upload error on unsuccessfull upload', () => {
        cy.intercept('PUT','/api/user/updateSignature', { fixture: 'updateSignatureError.json' , statusCode: 500}).as('updateSignature')

        cy.get('[data-cy="signature-draw-upload"]').click()
        cy.get('[data-cy="signature-canvas-input"]').click(10,10)
        cy.get('[data-cy="use-signature-button"]').click()

        cy.get('[data-cy="signature-upload-error"]').should('be.visible')

        cy.get('[data-cy="close-signature-upload-error"]').click()

        cy.get('[data-cy="signature-upload-error"]').should('not.exist')
    })

    it('opens signature view on "View signature" button', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json', delay: 2000 }).as('getSignature')

        cy.get('[data-cy="signature-view-button"]').click()

        cy.get('[data-cy="signature-download-loading"]').should('be.visible')

        cy.get('[data-cy="signature-view"]').should('be.visible')
    })

    it('logout button clears cookies and navigates to login', () => {
        cy.get('[data-cy="logout-button"').click()

        cy.url().should('include','login')
        cy.getCookie('accessToken').should('not.exist')
        cy.getCookie('refreshToken').should('not.exist')
    })

    it('Profileview opens and closes', () => {
        //Closes on button click
        cy.get('[data-cy="profile-view-button"]').click()

        cy.get('[data-cy="profile-view"]').should('not.exist')
        
        //Closes on outside click
        cy.get('[data-cy="profile-view-button"]').click()
        
        cy.get('[data-cy="home-page"]').click(10, 10)
        
        cy.get('[data-cy="profile-view"]').should('not.exist')
    })
  })