/// <reference types="cypress" />

describe('ReceiverSignature', () => {

    beforeEach(() => {
        cy.intercept('GET','/api/user/getContractByUserId**', { fixture: 'getContractByUserId.json'}).as('getContractByUserId')
        cy.intercept('POST','/api/user/isUserSigned', { fixture: false }).as('isUserSigned')
        cy.intercept('POST','/api/pdf/editContractForReceiver', { fixture: 'editContractFirstSignature.json' }).as('editContractForReceiver')

        cy.visit('/sign-nda/cbd56788-a3a5-4576-b472-0e8a214b5196')

        cy.wait(['@getContractByUserId','@isUserSigned'])
    })

    it('blocks send button if no signature uploaded', () => {
        cy.get('[data-cy="send-contract-button"]').should('be.disabled')
    })

    it('makes editContract request when user uploads by file', () => {
        cy.get('[data-cy="signature-file-input-button"]').click()   
        cy.fixture('test_signature.png').as('signatureFixture')
        cy.get('[data-cy="signature-file-input"]').selectFile('@signatureFixture', { force: true })

        cy.wait('@editContractForReceiver').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })
    })

    it('makes editContract request when user uploads by drawing', () => {
        cy.get('[data-cy="signature-draw-button"]').click()   
        cy.get('[data-cy="signature-canvas-input"]').click(25,25)
        cy.get('[data-cy="use-signature-button"]').click()

        cy.wait('@editContractForReceiver').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })
    })

    it('shows empty signaturecanvas warning when trying to submit empty signature', () => {
        cy.get('[data-cy="signature-draw-button"]').click()
        cy.get('[data-cy="use-signature-button"]').click()

        cy.get('[data-cy="empty-signature-warning"]').should('be.visible')
    })

    it('navigates to confirmation on send', () => {
        cy.get('[data-cy="signature-draw-button"]').click()   
        cy.get('[data-cy="signature-canvas-input"]').click(25,25)
        cy.get('[data-cy="use-signature-button"]').click()

        cy.get('[data-cy="send-contract-button"]').click()

        cy.url().should('include','confirmation')
    })
})