/// <reference types="cypress" />

describe('SenderSignature', () => {

    beforeEach(() => {
        cy.intercept('GET', '/api/user/users?groupslug=svomming', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        cy.intercept('GET', '/api/user/users?groupslug=', { fixture: 'svommingGroupUsers.json' }).as('getUsers')
        //This can be removed when homepage no longer loads empty group
        cy.intercept('GET','/api/group/groups',{ fixture: 'groups.json' }).as('getGroups')
        cy.intercept('GET','/api/user/loggedInUser', { fixture: 'loggedInUserInfo.json' }).as('loggedInUser')

        cy.visit('/login')

        cy.get('[data-cy="phone-input"]').click().type('98765432')
        cy.get('[data-cy="password-input"]').click().type('hs69')
        cy.get('[data-cy="login-submit"]').click()

        cy.wait(['@getUsers','@getGroups'])
    })

    it('uploads signature automatically', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractFirstSignature.json' }).as('editContract')
        cy.intercept('POST','/api/user/doesUserExist', { fixture: false }).as('doesUserExist')
        cy.intercept('POST','/api/user/addUser', { fixture: 'addUserResponse.json'}).as('addUser')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait('@getSignature')

        cy.get('[data-cy="signature-file-input-button"]').contains('Signatur lastet opp')

        cy.get('[data-cy="send-contract-button"]').click()

        cy.wait(['@doesUserExist','@addUser'])

        cy.url().should('include','/confirmation')
    })

    it('blocks send button if no signature uploaded', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'noSignaturePresent.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])

        cy.get('[data-cy="send-contract-button"]').should('be.disabled')
    })

    it('makes editContract request when user uploads by file', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'noSignaturePresent.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])

        cy.get('[data-cy="signature-file-input-button"]').click()   
        cy.fixture('test_signature.png').as('signatureFixture')
        cy.get('[data-cy="signature-file-input"]').selectFile('@signatureFixture', { force: true })

        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractFirstSignature.json' }).as('editContract')

        cy.wait('@editContract').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })
    })

    it('makes editContract request when user uploads by drawing', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'noSignaturePresent.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])
        
        cy.get('[data-cy="signature-draw-button"]').click()   
        cy.get('[data-cy="signature-canvas-input"]').click(25,25)
        cy.get('[data-cy="use-signature-button"]').click()

        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractFirstSignature.json' }).as('editContract')

        cy.wait('@editContract').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })
    })

    it('shows empty signaturecanvas warning when trying to submit empty signature', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'noSignaturePresent.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])
        
        cy.get('[data-cy="signature-draw-button"]').click()
        cy.get('[data-cy="use-signature-button"]').click()

        cy.get('[data-cy="empty-signature-warning"]').should('be.visible')
    })

    it('makes addUser request when sending contract to new user', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')
        cy.intercept('POST','/api/user/doesUserExist', { fixture: false }).as('doesUserExist')
        cy.intercept('POST','/api/user/addUser', { fixture: 'addUserResponse.json'}).as('addUser')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])

        cy.get('[data-cy="signature-file-input-button"]').click()   
        cy.fixture('test_signature.png').as('signatureFixture')
        cy.get('[data-cy="signature-file-input"]').selectFile('@signatureFixture', { force: true })

        cy.get('[data-cy="send-contract-button"]').click()

        cy.wait('@addUser').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })

        cy.url().should('include','confirmation')
    })

    it('makes resetContractByEmail request when sending contract to existing user', () => {
        cy.intercept('POST','/api/user/getSignature', { fixture: 'userSignature.json' }).as('getSignature')
        cy.intercept('POST','/api/pdf/editContract', { fixture: 'editContractNoSignature.json'}).as('editContract')
        cy.intercept('POST','/api/user/doesUserExist', { fixture: 'doesUserExist.json' }).as('doesUserExist')
        cy.intercept('PUT','/api/user/resetContractByEmail', { fixture: 'resetContractByEmailResponse.json'}).as('resetContractByEmail')

        cy.get('[data-cy="generate-contract-button"]:not(:hidden)').first().click()

        cy.wait(['@getSignature','@editContract'])

        cy.get('[data-cy="signature-file-input-button"]').click()   
        cy.fixture('test_signature.png').as('signatureFixture')
        cy.get('[data-cy="signature-file-input"]').selectFile('@signatureFixture', { force: true })

        cy.get('[data-cy="send-contract-button"]').click()

        cy.wait('@resetContractByEmail').then((interception) => {
            expect(interception.response.statusCode).to.equal(200)
        })

        cy.url().should('include','confirmation')
    })

})