import { Routes, Route, Navigate } from 'react-router-dom';
import LoginPage from './pages/Login';
import HomePage from './pages/Home';
import ConfirmationPage from './pages/Confirmation';
import NotFound from './pages/NotFound';
import ProtectRoutes from './utils/protectedRoutes';
import { useState } from 'react';
import { UserContext, UserInfo } from './contexts/UserContextProps';
import SenderSignaturePage from './pages/SenderSignature';
import ReceiverSignaturePage from './pages/ReceiverSignature';

function App() {
	const [userInfo, setUserInfo] = useState<UserInfo>({
		first_name: '',
		last_name: '',
		email: '',
		ntnuiNo: 0,
		memberships: [],
		userInHS: false
	});

	return (
		<UserContext.Provider value={{ userInfo, setUserInfo }}>
			<Routes>
				<Route path='/login' element={<LoginPage />} />
				<Route element={<ProtectRoutes />}>
					<Route path='/' element={<HomePage />} />
					<Route path='/send-nda' element={<SenderSignaturePage />} />
				</Route>
				<Route
					path='/sign-nda/:userid'
					element={<ReceiverSignaturePage />}
				/>
				<Route path='/confirmation' element={<ConfirmationPage />} />
				<Route path='/not-found' element={<NotFound />} />
				<Route path='*' element={<Navigate to='/not-found' />} />
			</Routes>
		</UserContext.Provider>
	);
}

export default App;
