import { useRef, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import Modal from 'react-modal';
import { IconInfoCircle, IconX } from '@tabler/icons-react';

//Button that opens a form for manually sending contracts by mail
const SendByMailButton = () => {
	const [sendMailModalOpen, setSendMailModalOpen] = useState(false);
	const [buttonInfoIsShown, setButtonInfoIsShown] = useState(false);
	const emailInputRef = useRef<HTMLInputElement>(null);
	const firstnameInputRef = useRef<HTMLInputElement>(null);
	const lastnameInputRef = useRef<HTMLInputElement>(null);
	const roleInputRef = useRef<HTMLInputElement>(null);
	const groupInputRef = useRef<HTMLInputElement>(null);
	const navigate = useNavigate();

	const sendEmail = () => {
		const user = {
			first_name: firstnameInputRef.current?.value,
			last_name: lastnameInputRef.current?.value,
			email: emailInputRef.current?.value,
			role: roleInputRef.current?.value
		};

		const group = {
			name: groupInputRef.current?.value,
			//All volunteers who are not board-members are assign to the frivillige group
			slug: 'frivillige'
		};

		navigate('/send-nda', {
			state: {
				user: user,
				group: group
			}
		});
	};

	return (
		<>
			<div className='flex items-center justify-center'>
				<div className='relative'>
					{buttonInfoIsShown && (
						<div className='absolute top-[-30px] right-[30px] z-50'>
							<div className='flex w-64 flex-col items-center justify-center rounded-md bg-custom-popup-dark p-1 text-center'>
								<p className='mb-1 flex items-center justify-center font-semibold text-white'>
									Her kan du sende kontrakter til emailer som
									ikke er registrert i medlemssystemet
								</p>
							</div>
						</div>
					)}
					<IconInfoCircle
						onMouseEnter={() => setButtonInfoIsShown(true)}
						onMouseLeave={() => setButtonInfoIsShown(false)}
						size={18}
						className='mr-1 text-white'
					/>
				</div>
				<button
					onClick={() => setSendMailModalOpen(true)}
					className='py px h-8 w-32 rounded bg-custom-blue text-xs text-white hover:bg-custom-light-blue sm:text-sm'
					data-cy='send-by-mail-button'>
					Send til frivillige
				</button>
			</div>
			<Modal
				style={{
					overlay: {
						backgroundColor: 'rgba(26,32,44,0.5)'
					}
				}}
				isOpen={sendMailModalOpen}
				className='z-50 flex h-screen items-center justify-center'
				ariaHideApp={false}
				onRequestClose={() => setSendMailModalOpen(false)}>
				<div className='flex flex-col rounded-md border border-gray-400 bg-custom-dark text-white' data-cy='send-by-mail-button'>
					<div className='flex justify-end'>
						<IconX
							size={30}
							onClick={() => setSendMailModalOpen(false)}
							className='m-2 justify-self-end rounded-full hover:bg-gray-700'
						/>
					</div>
					<div className='mx-5 flex flex-row items-center justify-center'>
						<form
							onSubmit={(event) => {
								event.preventDefault();
								const email = emailInputRef.current?.value;
								if (email && email.length > 0) {
									sendEmail();
								}
							}}
							className='flex flex-col items-center justify-self-end'>
							<label htmlFor='emailInput'>
								Email å sende kontrakten til:
							</label>
							<input
								ref={emailInputRef}
								type='email'
								name='emailInput'
								id='emailInput'
								required
								placeholder='Email'
								className='col-span-3 my-2 mr-5 ml-2 mb-10 rounded-md border bg-custom-dark pl-1 text-white outline-none placeholder:pl-1'
								data-cy='send-by-mail-email-input'
							/>
							<label htmlFor='firstnameInput'>
								Navn som skal stå i kontrakten:
							</label>
							<input
								ref={firstnameInputRef}
								type='text'
								name='firstnameInput'
								id='firstnameInput'
								required
								placeholder='Fornavn'
								className='col-span-3 my-2 mr-5 ml-2 rounded-md border bg-custom-dark pl-1 text-white outline-none placeholder:pl-1'
								data-cy='send-by-mail-firstname-input'
							/>
							<input
								ref={lastnameInputRef}
								type='text'
								name='lastnameInput'
								id='lastnameInput'
								required
								placeholder='Etternavn'
								className='col-span-3 my-2 mr-5 ml-2 mb-5 rounded-md border bg-custom-dark pl-1 text-white outline-none placeholder:pl-1'
								data-cy='send-by-mail-lastname-input'
							/>
							<label htmlFor='roleInput'>
								Rolle og gruppe som skal stå i kontrakten:
							</label>
							<input
								ref={roleInputRef}
								type='text'
								name='roleInput'
								id='roleInput'
								required
								placeholder='Rolle'
								className='col-span-3 my-2 mr-5 ml-2 rounded-md border bg-custom-dark pl-1 text-white outline-none placeholder:pl-1'
								data-cy='send-by-mail-role-input'
							/>
							<input
								ref={groupInputRef}
								type='text'
								name='groupInputRef'
								id='groupInputRef'
								required
								placeholder='Gruppe'
								className='col-span-3 my-2 mr-5 ml-2 rounded-md border bg-custom-dark pl-1 text-white outline-none placeholder:pl-1'
								data-cy='send-by-mail-group-input'
							/>
							<button
								type='submit'
								className='my-2 h-[2em] w-[5em] rounded bg-custom-blue text-xs text-white hover:bg-custom-light-blue sm:text-sm'
								data-cy='send-by-mail-submit'>
								Bruk
							</button>
						</form>
					</div>
				</div>
			</Modal>
		</>
	);
};

export default SendByMailButton;
