import { useState, useRef } from 'react';
import SignatureCanvas from 'react-signature-canvas';
import Modal from 'react-modal';
import { IconX } from '@tabler/icons-react';

//Canvas for drawing a signature
const Sign = (props: {
	isOpen: boolean;
	setIsOpen: any;
	onSave: (dataURL: string) => void;
}) => {
	const sigCanvas = useRef<SignatureCanvas>(null);

	const [showEmptyWarning, setShowEmptyWarning] = useState(false);

	const saveSignature = () => {
		if (!sigCanvas.current?.isEmpty()) {
			const dataURL = sigCanvas.current
				?.getTrimmedCanvas()
				.toDataURL('image/png');
			if (dataURL) props.onSave(dataURL);
			props.setIsOpen(false);
		} else {
			setShowEmptyWarning(true);
		}
	};

	return (
		<Modal
			style={{
				overlay: {
					backgroundColor: 'rgba(26,32,44,0.5)'
				}
			}}
			isOpen={props.isOpen}
			className='flex h-screen items-center justify-center'
			ariaHideApp={false}>
			<div className='w-min rounded-md border border-gray-400 bg-custom-dark text-white'>
				<div className='m-2 flex flex-row justify-between text-2xl'>
					<p>Signer</p>
					<IconX
						size={32}
						onClick={() => props.setIsOpen(false)}
						className='rounded-full hover:bg-gray-700'
					/>
				</div>
				<p className='mx-2 text-sm italic'>Tips: Vend telefonen</p>
				<div className='mx-2' data-cy='signature-canvas-input'>
					<SignatureCanvas
						penColor='black'
						backgroundColor='white'
						canvasProps={{
							width: 700,
							height: 200,
							style: {
								border: '1px dashed black',
								margin: '5px 0'
							}
						}}
						onBegin={() => setShowEmptyWarning(false)}
						ref={sigCanvas}
					/>
				</div>
				<div className='relative'>
					<div className='m-2 flex flex-row justify-between text-base'>
						<button
							onClick={() => sigCanvas.current?.clear()}
							className='rounded-sm border-gray-500 bg-gray-500 px-3 py-1 text-center font-semibold text-white hover:bg-gray-400'>
							Start på nytt
						</button>
						<button
							onClick={saveSignature}
							className='rounded-sm border-custom-blue bg-custom-blue px-3 py-1 text-center font-semibold text-white hover:bg-custom-light-blue'
							data-cy='use-signature-button'>
							Bruk
						</button>
						{showEmptyWarning && (
							<div className='absolute right-[15em]'>
								<p className='text-white' data-cy='empty-signature-warning'>
									Vennligst skriv inn en signatur
								</p>
							</div>
						)}
					</div>
				</div>
			</div>
		</Modal>
	);
};

export default Sign;
