import { IconArrowNarrowLeft, IconArrowNarrowRight } from '@tabler/icons-react';
import { useEffect, useRef, useState } from 'react';

//Dropdownmenu for selecting a sign_date year to filter users by
const YearPicker = (props: { setYearForFilter: any; year: number }) => {
	const [year, setYear] = useState<number>(props.year);
	const [allYearsSelected, setAllYearsSelected] = useState(true);
	const [yearListIsShown, setYearListIsShown] = useState(false);
	const [currentYearPage, setCurrentYearPage] = useState(0);
	const ref = useRef<HTMLDivElement>(null);

	useEffect(() => {
		function handleClickOutside(event: MouseEvent): void {
			if (ref.current && !ref.current.contains(event.target as Node)) {
				setYearListIsShown(false);
			}
		}
		document.addEventListener('mousedown', handleClickOutside);
		return () => {
			document.removeEventListener('mousedown', handleClickOutside);
		};
	});

	const lowerYear = 1910;
	const currentYear = new Date().getFullYear();
	const yearPages = [];

	const years = [];
	for (let year = lowerYear; year <= currentYear; year++) {
		years.push(
			<div
				onClick={() => {
					setYear(year);
					setYearListIsShown(false);
					setAllYearsSelected(false);
					props.setYearForFilter(year);
				}}
				key={year}
				className='w-14 border p-2 hover:bg-gray-300'
				data-cy='specific-year-button'>
				<p>{year}</p>
			</div>
		);
	}

	const pageSize = 15;
	for (let i = years.length; i >= 0; i -= pageSize) {
		let lowerIndex = i - pageSize;
		if (lowerIndex < 0) lowerIndex = 0;
		const page = years.slice(lowerIndex, i);
		yearPages.push(page);
	}

	const onBackArrow = () => {
		if (currentYearPage < yearPages.length - 1)
			setCurrentYearPage(currentYearPage + 1);
	};

	const onForwardArrow = () => {
		if (currentYearPage > 0) 
			setCurrentYearPage(currentYearPage - 1);
	};

	return (
		<div ref={ref} className='relative'>
			<button
				onClick={() => setYearListIsShown(!yearListIsShown)}
				className='ml-2 flex h-full w-16 items-center justify-center rounded bg-custom-blue text-white hover:bg-custom-light-blue'
				data-cy='yearpicker-button'>
				{allYearsSelected ? 'Alle år' : year}
			</button>
			{yearListIsShown && (
				<div className='absolute top-[2rem] left-[-6.5rem] w-72 rounded bg-white p-1' data-cy='year-picker'>
					<div className='flex justify-between'>
						<div className='flex w-full flex-row items-center justify-evenly'>
							<IconArrowNarrowLeft
								onClick={onBackArrow}
								className='hover:stroke-slate-400'
								size={25}
							/>
							<button
								onClick={() => {
									setAllYearsSelected(true);
									setYearListIsShown(false);
									props.setYearForFilter(0);
								}}
								className='my-1 rounded border bg-custom-blue p-1 text-white'>
								Se alle år
							</button>
							<IconArrowNarrowRight
								onClick={onForwardArrow}
								className='hover:stroke-slate-400'
								size={25}
							/>
						</div>
					</div>
					<div className='flex flex-wrap'>
						{yearPages[currentYearPage]}
					</div>
				</div>
			)}
		</div>
	);
};

export default YearPicker;
