import UserSearch from '../Functionalities/UserSearch';
import GroupSelector from '../Functionalities/GroupSelector';
import YearPicker from '../Functionalities/YearPicker';
import SignStatusFilterButton from '../Functionalities/SignStatusFilterButton';
import FilterMenu from '../Menus/FilterMenu';
import SendByMailButton from '../Functionalities/SendByMailButton';
import FunctionalityMenu from '../Menus/FunctionalityMenu';
import { useContext } from 'react';
import { UserContext, UserContextProps } from '../../contexts/UserContextProps';

import { User } from '../../types/user';
import { Group } from '../../types/group';
import { DownloadContractsButton } from '../Functionalities/DownloadContractsButton';

//Actionbar containing filtering options and other functionalitites
const TopBar = (props: {
	users: User[];
	setUsers: any;
	setGroupFilter: any;
	group: Group;
	setYearForFilter: any;
	year: number;
	setShowSignedUsers: any;
	showSignedUsers: boolean;
}) => {
	const { userInfo } = useContext(UserContext) as UserContextProps;

	return (
		<>
			<div className='flex flex-row items-center justify-between'>
				<div className='flex flex-row items-center'>
					<UserSearch users={props.users} setUsers={props.setUsers} />
					<div className={userInfo.userInHS ? 'hidden lg:flex' : ''}>
						<SignStatusFilterButton
							setShowSignedUsers={props.setShowSignedUsers}
							showSignedUsers={props.showSignedUsers}
						/>
					</div>
					<div className='hidden h-8 lg:flex'>
						<GroupSelector
							setGroupFilter={props.setGroupFilter}
							group={props.group}
						/>
						{userInfo.userInHS && (
							<>
								<YearPicker
									setYearForFilter={props.setYearForFilter}
									year={props.year}
								/>
							</>
						)}
					</div>
					<div className={userInfo.userInHS ? 'lg:hidden' : 'hidden'}>
						<FilterMenu
							users={props.users}
							setUsers={props.setUsers}
							setShowSignedUsers={props.setShowSignedUsers}
							showSignedUsers={props.showSignedUsers}
							setGroupFilter={props.setGroupFilter}
							group={props.group}
							setYearForFilter={props.setYearForFilter}
							year={props.year}
						/>
					</div>
				</div>
				<div className='hidden xl:flex'>
					<DownloadContractsButton group={props.group} />
					<SendByMailButton />
				</div>
				<div className='xl:hidden'>
					<FunctionalityMenu group={props.group} />
				</div>
			</div>
		</>
	);
};

export default TopBar;
