import { IconInfoCircle, IconLock, IconEye, IconX } from '@tabler/icons-react';
import { useNavigate } from 'react-router-dom';
import { useEffect, useRef, useState } from 'react';
import PhoneInput from 'react-phone-input-2';
import 'react-phone-input-2/lib/style.css';
import '../../styles/phoneinput.css';
import axios from 'axios';
import { ClipLoader } from 'react-spinners';

const LoginForm = () => {
	const [phonenumber, setPhonenumber] = useState('');
	const [passwordVisible, setPasswordVisible] = useState(false);
	const [phonenumberIsValid, setPhonenumberIsValid] = useState(true);
	const [phoneInfoIsShown, setPhonenumberInfoShown] = useState(false);
	const [passwordInfoIsShown, setPasswordInfoShown] = useState(false);
	const [passwordBorderColor, setPasswordBorderColor] =
		useState('border-white');
	const [isLoading, setIsLoading] = useState(false);
	const [showLoginFailedWarning, setShowLoginFailedWarning] = useState(false);
	const passwordRef = useRef<HTMLInputElement>(null);
	const navigate = useNavigate();

	//Reroutes the user to homepage if they are authorized
	useEffect(() => {
		axios.get('/api/auth/checkToken').then((response) => {
			if (response.data.validToken) navigate('/');
		}).catch((error) => {
		});
	}, []);

	const formatCheck = () => {
		setPhonenumberIsValid(phonenumber.length >= 7);
	};

	const login = async (phone_number: string, password: string) => {
		try {
			return await axios.post('/api/auth/login', {
				phone_number: phone_number,
				password: password
			});
		} catch (error) {
			console.log(error);
			throw error;
		}
	};

	const loginHandler = (phone_number: string, password: string) => {
		formatCheck();
		setIsLoading(true);
		login(phone_number, password)
			.then((response) => {
				setIsLoading(false);
				navigate('/');
			})
			.catch(() => {
				setShowLoginFailedWarning(true);
				setIsLoading(false);
			});
	};

	return (
		<>
			{!isLoading && (
				<form
					onSubmit={(event) => {
						event.preventDefault();
						const password = passwordRef.current?.value;
						if (password) {
							loginHandler(phonenumber, password);
						}
					}}
					className='mx-auto w-full max-w-[375px] p-4 text-white'>
					<div className='flex flex-col py-2'>
						{phoneInfoIsShown && (
							<div className='relative'>
								<div className='absolute bottom-1/4 right-36'>
									<div className='flex w-64 flex-col items-center justify-center rounded-md bg-custom-popup-dark p-1 text-center'>
										<p className='mb-1 flex items-center justify-center font-semibold'>
											Logg inn med det samme telefonnummer
											som du bruker på
										</p>
										<p className='text-custom-blue'>
											medlem.ntnui.no
										</p>
									</div>
								</div>
							</div>
						)}
						<div className='flex items-center py-2'>
							<label className='pr-1 font-bold'>Telefon </label>
							<IconInfoCircle
								onMouseEnter={() =>
									setPhonenumberInfoShown(true)
								}
								onMouseLeave={() =>
									setPhonenumberInfoShown(false)
								}
								size={18}
							/>
						</div>
						<div data-cy='phone-input'>
							<PhoneInput
								country={'no'}
								value={phonenumber}
								onChange={(phonenumber: any) => {
									setPhonenumber('+' + phonenumber);
									setPhonenumberIsValid(true);
									setShowLoginFailedWarning(false);
								}}
								placeholder='Telefonnummer'
								enableSearch={true}
							/>
						</div>
						{!phonenumberIsValid && (
							<div className='relative'>
								<p className='bottom-68 absolute left-1/3 text-custom-red'>
									Formatet er ugyldig
								</p>
							</div>
						)}
					</div>
					<div>
						{passwordInfoIsShown && (
							<div className='relative'>
								<div className='absolute bottom-1/4 right-36'>
									<div className='flex w-64 flex-col items-center justify-center rounded-md bg-custom-popup-dark p-1 text-center'>
										<p className='mb-1 flex items-center justify-center font-semibold'>
											Logg inn med det samme passord som
											du bruker på
										</p>
										<p className='text-custom-blue'>
											medlem.ntnui.no
										</p>
									</div>
								</div>
							</div>
						)}
						<div className='flex items-center py-2'>
							<label className='pr-1 font-bold'>Passord </label>
							<IconInfoCircle
								onMouseEnter={() => setPasswordInfoShown(true)}
								onMouseLeave={() => setPasswordInfoShown(false)}
								size={18}
							/>
						</div>
						<div className='flex flex-row'>
							<div
								onClick={() => {
									setPasswordBorderColor(
										'border-custom-blue'
									);
								}}
								className={
									'flex w-full flex-row items-center rounded-tl rounded-bl border ' +
									passwordBorderColor
								}>
								<IconLock size={18} className='mx-2 h-full' />
								<input
									type={passwordVisible ? 'text' : 'password'}
									onBlur={() =>
										setPasswordBorderColor('border-white')
									}
									onChange={() =>
										setShowLoginFailedWarning(false)
									}
									placeholder='Passord'
									required={true}
									ref={passwordRef}
									className='h-8 w-full bg-custom-dark focus:outline-none'
									data-cy='password-input'
								/>
							</div>
							<div
								onClick={() =>
									setPasswordVisible(!passwordVisible)
								}
								className='flex cursor-pointer content-around rounded-tr rounded-br border bg-white px-2 hover:bg-slate-300'>
								<IconEye
									size={18}
									className='h-full w-full stroke-gray-500'
								/>
							</div>
						</div>
					</div>
					<button
						type='submit'
						className='mt-6 h-1/2 w-full rounded-md border-custom-blue bg-custom-blue text-center text-lg font-black hover:bg-custom-light-blue disabled:cursor-not-allowed'
						data-cy='login-submit'>
						LOGG INN
					</button>
					{showLoginFailedWarning && (
						<div className='my-4 flex items-center justify-between rounded-lg border border-red-500 px-4 py-2' data-cy='login-error'>
							<IconX
								size={48}
								className='mx-2 text-red-500'></IconX>
							<p className='font-bold text-white'>
								Kunne ikke logge inn. <br />
								Prøv annet telefonnummer eller passord
							</p>
						</div>
					)}
				</form>
			)}
			{isLoading && (
				<div className='mt-16 flex flex-col items-center justify-center' data-cy='login-loading'>
					<ClipLoader size={80} color='#FFFFFF' />
					<p className='mt-3em text-[2em] text-white'>
						Logger inn...
					</p>
				</div>
			)}
		</>
	);
};

export default LoginForm;
