import { useEffect, useRef, useState } from 'react';
import GroupSelector from '../Functionalities/GroupSelector';
import SignStatusFilterButton from '../Functionalities/SignStatusFilterButton';
import YearPicker from '../Functionalities/YearPicker';
import { IconAdjustmentsAlt } from '@tabler/icons-react';
import { User } from '../../types/user';
import { Group } from '../../types/group';

//Menu displayed on smaller screen-sizes containing filtering-options
const FilterMenu = (props: {
	users: User[];
	setUsers: any;
	setGroupFilter: any;
	group: Group;
	setYearForFilter: any;
	year: number;
	setShowSignedUsers: any;
	showSignedUsers: boolean;
}) => {
	const [menuVisible, setMenuVisible] = useState(false);
	const ref = useRef<HTMLDivElement>(null);

	useEffect(() => {
		function handleClickOutside(event: MouseEvent): void {
			if (ref.current && !ref.current.contains(event.target as Node)) {
				setMenuVisible(false);
			}
		}
		document.addEventListener('mousedown', handleClickOutside);
		return () => {
			document.removeEventListener('mousedown', handleClickOutside);
		};
	});

	return (
		<div ref={ref} className='relative'>
			<div
				onClick={() => setMenuVisible(!menuVisible)}
				className='hover:bg-gray absolute top-[-17px] cursor-pointer rounded-md border hover:border-2'>
				<IconAdjustmentsAlt
					size={25}
					className='h-8 w-8 p-1 text-white'
				/>
			</div>
			{menuVisible && (
				<div className='absolute top-[25px] left-[-100px] rounded-md border bg-custom-dark p-2'>
					<div className='flex flex-col items-center justify-center'>
						<GroupSelector
							setGroupFilter={props.setGroupFilter}
							group={props.group}
						/>
						<div className='mt-2 flex'>
							<SignStatusFilterButton
								setShowSignedUsers={props.setShowSignedUsers}
								showSignedUsers={props.showSignedUsers}
							/>
							<YearPicker
								setYearForFilter={props.setYearForFilter}
								year={props.year}
							/>
						</div>
					</div>
				</div>
			)}
		</div>
	);
};

export default FilterMenu;
