import { IconMenu2 } from '@tabler/icons-react';
import SendByMailButton from '../Functionalities/SendByMailButton';
import { useEffect, useRef, useState } from 'react';
import { DownloadContractsButton } from '../Functionalities/DownloadContractsButton';
import { Group } from '../../types/group';

//Menu displayed on smaller screen-sizes containing various functionality
const FunctionalityMenu = (props: { group: Group }) => {
	const [menuVisible, setMenuVisible] = useState(false);
	const [childModalOpen, setChildModalOpen] = useState(false);
	const ref = useRef<HTMLDivElement>(null);

	useEffect(() => {
		function handleClickOutside(event: MouseEvent): void {
			if (
				ref.current &&
				!ref.current.contains(event.target as Node) &&
				!childModalOpen
			) {
				setMenuVisible(false);
			}
		}
		document.addEventListener('mousedown', handleClickOutside);
		return () => {
			document.removeEventListener('mousedown', handleClickOutside);
		};
	});

	return (
		<div ref={ref} className='relative'>
			<div
				onClick={() => setMenuVisible(!menuVisible)}
				className='hover:bg-gray absolute top-[-17px] right-[1px] cursor-pointer rounded-md border hover:border-2'>
				<IconMenu2 size={25} className='h-8 w-8 p-1 text-white' />
			</div>
			{menuVisible && (
				<div className='absolute top-[25px] left-[-179px] rounded-md border bg-custom-dark p-2'>
					<div
						onClick={() => setChildModalOpen(true)}
						className='flex flex-col items-start gap-3'>
						<div>
							<DownloadContractsButton group={props.group} />
						</div>
						<div>
							<SendByMailButton />
						</div>
					</div>
				</div>
			)}
		</div>
	);
};

export default FunctionalityMenu;
