import { useState, useEffect } from 'react';
import { Outlet, Navigate } from 'react-router-dom';
import axios from 'axios';
import { ClipLoader } from 'react-spinners';

//Redirects the user to the loginpage if a valid accessToken does not exist
function ProtectRoutes() {
	const [validToken, setValidToken] = useState(false);
	const [loading, setLoading] = useState(true);

	useEffect(() => {
		async function checkToken() {
			try {
				const response = await axios.get('/api/auth/checkToken');
				setValidToken(response.data.validToken);
			} catch (error) {
				console.error(error);
			}
			setLoading(false);
		}

		checkToken();
	}, []);

	if (loading) {
		return (
			<div className='absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 transform'>
				<ClipLoader size={80} color='#FFFFFF' />
				<p className='mt-3em text-[2em] text-white'>Laster...</p>
			</div>
		);
	}

	return validToken === true ? <Outlet /> : <Navigate to='/login' />;
}

export default ProtectRoutes;
